@@ -9,7 +9,7 @@
  *    Define, and export BONOBO_ACTIVATION_DEBUG_OUTPUT
  * for a smoother, closer debugging experience.
  */
-#undef BONOBO_ACTIVATION_DEBUG
+#define BONOBO_ACTIVATION_DEBUG
 
 /*
  *    Time delay after all servers are de-registered / dead
@@ -21,16 +21,15 @@
 
 /* object-directory-corba.c */
 void                   bonobo_object_directory_init        (PortableServer_POA     poa,
-                                                            const char            *domain,
                                                             const char            *source_directory,
                                                             CORBA_Environment     *ev);
 void                   bonobo_object_directory_shutdown    (PortableServer_POA     poa,
                                                             CORBA_Environment     *ev);
 Bonobo_ObjectDirectory bonobo_object_directory_get         (void);
-CORBA_Object           bonobo_object_directory_re_check_fn (const char            *display,
-                                                            const char            *od_iorstr,
-                                                            gpointer               user_data,
-                                                            CORBA_Environment     *ev);
+CORBA_Object           bonobo_object_directory_re_check_fn (const Bonobo_ActivationEnvironment *environment,
+                                                            const char                         *od_iorstr,
+                                                            gpointer                            user_data,
+                                                            CORBA_Environment                  *ev);
 void                   bonobo_object_directory_reload      (void);
 void                   reload_object_directory             (void);
 void                   check_quit                          (void);
@@ -39,8 +38,7 @@ void                   check_quit                          (void);
 void                   bonobo_server_info_load             (char                 **dirs,
                                                             Bonobo_ServerInfoList *servers,
                                                             GHashTable           **by_iid,
-                                                            const char            *host, 
-                                                            const char            *domain);
+                                                            const char            *host);
 
 /* od-activate.c */
 typedef struct {
@@ -50,10 +48,11 @@ typedef struct {
 } ODActivationInfo;
 
 /* object-directory-activate.c */
-CORBA_Object             od_server_activate              (Bonobo_ServerInfo *si,
-                                                          ODActivationInfo  *actinfo,
-                                                          CORBA_Object       od_obj,
-                                                          CORBA_Environment *ev);
+CORBA_Object             od_server_activate              (Bonobo_ServerInfo                  *si,
+                                                          ODActivationInfo                   *actinfo,
+                                                          CORBA_Object                        od_obj,
+                                                          const Bonobo_ActivationEnvironment *environment,
+                                                          CORBA_Environment                  *ev);
 
 /* activation-context-corba.c */
 void                     activation_context_init         (PortableServer_POA     poa,
@@ -66,7 +65,6 @@ Bonobo_ActivationContext activation_context_get          (void);
 void                     activation_clients_cache_notify (void);
 gboolean                 activation_clients_is_empty_scan(void);
 void                     add_initial_locales             (void);
-
-gboolean                 is_locale_interesting           (const char *locale);
+gboolean                 register_interest_in_locales    (const char            *locales);
 
 #endif /* SERVER_H */
